Name:		qemu
Version:	0.9.1
Release:	1
Url:		http://www.qemu.org
License:	BSD 3-Clause, GPL v2 or later
Group:		System/Emulators/PC
Summary:	Universal CPU emulator
Source0:	%{name}-%{version}.tar.gz
Patch0:		%{name}-%{version}-pre-TCG.patch
Patch1:		%{name}-%{version}-aix.patch
Patch2:		%{name}-%{version}-no_debug_symbols.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-build

BuildRequires:	patch, make, coreutils

BuildRequires:	gcc >= 4.2.3-2
BuildRequires:	SDL-devel >= 1.2.14-3
BuildRequires:	zlib-devel

Requires:	SDL >= 1.2.14-3
Requires:	zlib

%ifos aix5.3
%define buildhost powerpc-ibm-aix5.3.0.0
Requires: AIX-rpm >= 5.3.0.0
Requires: AIX-rpm < 5.4.0.0
%endif
%ifos aix6.1
%define buildhost powerpc-ibm-aix6.1.0.0
Requires: AIX-rpm >= 6.1.0.0
Requires: AIX-rpm < 6.2.0.0
%endif
%ifos aix7.1
%define buildhost powerpc-ibm-aix7.1.0.0
Requires: AIX-rpm >= 7.1.0.0
%endif

%description
QEMU is a FAST! processor emulator using dynamic translation to achieve good emulation speed.

QEMU emulates a full system (for example a PC), including one or several processors and various peripherals. It can be used to launch different Operating Systems without rebooting the PC or to debug system code.

For system emulation, the following hardware targets are supported:

    * PC (x86 or x86_64 processor)
    * ISA PC (old style PC without PCI bus)
    * PREP (PowerPC processor)
    * G3 BW PowerMac (PowerPC processor)
    * Mac99 PowerMac (PowerPC processor, in progress)
    * Sun4m/Sun4c/Sun4d (32-bit Sparc processor)
    * Sun4u (64-bit Sparc processor, in progress)
    * Malta board (32-bit and 64-bit MIPS processors)
    * ARM Integrator/CP (ARM)
    * ARM Versatile baseboard (ARM)
    * ARM RealView Emulation baseboard (ARM)
    * Spitz, Akita, Borzoi and Terrier PDAs (PXA270 processor)
    * Luminary Micro LM3S811EVB (ARM Cortex-M3)
    * Luminary Micro LM3S6965EVB (ARM Cortex-M3)
    * Freescale MCF5208EVB (ColdFire V2).
    * Arnewsh MCF5206 evaluation board (ColdFire V2).
    * Palm Tungsten|E PDA (OMAP310 processor) 


%prep
%setup -q
export PATH=/opt/freeware/bin:$PATH
%patch0 -p1
%patch1 -p1
%patch2


%build
export CC="gcc -D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE -D_LARGE_FILES"
export CFLAGS="-DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -O -I/opt/freeware/include"

export CXX=g++
export CXXFLAGS=${CFLAGS}

export LD=ld
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"

./configure \
    --prefix=%{_prefix} \
    --disable-vnc-tls

gmake %{?_smp_mflags}
gmake qemu.1
gmake qemu-img.1


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
export PATH=/opt/freeware/bin:$PATH
gmake install DESTDIR=${RPM_BUILD_ROOT}

/usr/bin/strip ${RPM_BUILD_ROOT}%{_sbindir}/* || :

mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man1
cp qemu.1 qemu-img.1 ${RPM_BUILD_ROOT}%{_mandir}/man1
chmod 0644 ${RPM_BUILD_ROOT}%{_mandir}/man1/*

cd ${RPM_BUILD_ROOT}
mkdir -p usr/bin
cd usr/bin
for f in qemu qemu-system-m68k qemu-system-mipsel qemu-system-sh4 qemu-img qemu-system-mips qemu-system-ppc qemu-system-sh4eb qemu-system-arm qemu-system-mips64 qemu-system-ppc64 qemu-system-sparc qemu-system-cris qemu-system-mips64el qemu-system-ppcemb qemu-system-x86_64 ; do
    ln -sf ../..%{_bindir}/${f} .
done


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc COPYING COPYING.LIB Changelog README TODO VERSION
%{_bindir}/qemu*
%{_mandir}/man1/*
%{_datadir}/%{name}
/usr/bin/qemu*


%changelog
* Wed Aug 11 2010 Michael Perzl <michael@perzl.org> - 0.9.1-1
- first version for AIX5L V5.3 and higher
- built on the excellent work done by Laurent Vivier <Laurent.Vivier@bull.com>
